# Data Flow Diagrams
### On this page
  * [Creating Data Flow Diagrams](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#creating-data-flow-diagrams)
  * [Using Data Flow Diagrams](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#using-data-flow-diagrams)
  * [Adding Applications](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#adding-applications)
  * [Linking Diagrams to Other Diagrams in](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#linking-diagrams-to-other-diagrams-in)
  * [Expanding Interfaces](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#expanding-interfaces)
  * [Applying Labels](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#applying-labels)
  * [Drill-Down and Roll-Up Application](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#drill-down-and-roll-up-application)
  * [Selecting Fact Sheets by Filter](https://help.sap.com/docs/leanix/ea/data-flow?version=CLOUD#selecting-fact-sheets-by-filter)


View all
Data flow diagrams in SAP LeanIX enable you to add and explore applications and their interfaces, providing a comprehensive understanding of data flow within their environment. You can visualize how data moves from one application to another, identify the supporting technologies, and gain insights into the specific data exchanged between applications.
Data flow diagrams are especially valuable in integration architecture scenarios, as they help you understand how applications are integrated and how they exchange information. For instance, when replacing an application, the diagram helps identify dependencies and the data transfer that needs to be recreated. Similarly, when adding a new application to the landscape, the diagram shows which existing applications need to be integrated based on the data they provide and the data the new application offers. In both cases, the data flow diagram provides crucial insights into the integration process and facilitates smooth transitions in the application landscape.
